/* libiriverdb - device autodetect routines
 * Copyright 2005 Matt Dainty
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * $Id: detect.c 40 2006-12-12 11:36:07Z matt $
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif /* HAVE_CONFIG_H */

#include <stdlib.h>
#include <glib.h>

#ifdef HAVE_DBUS
#define DBUS_API_SUBJECT_TO_CHANGE
#include <dbus/dbus.h>
#endif /* HAVE_DBUS */

#include "iriverdb.h"

#include "internal.h"

void iriverdb_detect_dbus( GList **detected );

GList *iriverdb_detect( void )
{
	GList *detected = NULL;

	/* Add various detection tests here
	 */
	iriverdb_detect_dbus( &detected );

	return detected;
}

/* Probe for devices using HAL via DBus
 */
void iriverdb_detect_dbus( GList **detected )
{
#ifdef HAVE_DBUS
	DBusConnection *connection;
	DBusError error;
	DBusMessage *message, *reply;

	dbus_error_init( &error );
	connection = dbus_bus_get( DBUS_BUS_SYSTEM, &error );

	dbus_connection_set_exit_on_disconnect( connection, FALSE );

	/* FIXME Do DBus/HAL probe stuff here
	 */

	dbus_connection_unref( connection );
#endif /* HAVE_DBUS */

	return;
}

GList *iriverdb_devices( void )
{
	GList *devices = NULL;

	iriverdb_device_t *device;

	if ( ( device = ( iriverdb_device_t * ) calloc( 1, sizeof( iriverdb_device_t ) ) ) == NULL ) {
		return devices;
	}

	/* iRiver H340
	 */
	device->vendor_id = 0x1006;
	device->product_id = 0x3003;
	device->version = IRIVERDB_016;

	devices = g_list_append( devices, device );

	return devices;
}
