/* libiriverdb - public api
 * Copyright 2005 Matt Dainty
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * $Id: iriverdb.h 30 2005-08-14 16:11:02Z  $
 */

#ifndef IRIVERDB_H
#define IRIVERDB_H

#include <glib.h>

#ifdef __cplusplus
extern "C" {
#endif

/* XXX These have to be in the same order as stored in the database
 */
enum {
	IRIVERDB_FIELD_FILENAME = 0,
	IRIVERDB_FIELD_SONGNAME,
	IRIVERDB_FIELD_ARTIST,
	IRIVERDB_FIELD_ALBUM,
	IRIVERDB_FIELD_GENRE,
	IRIVERDB_FIELD_MAX
};

/* These fields are UTF-8
 */
typedef struct iriverdb_data {
	char *field[IRIVERDB_FIELD_MAX];
} iriverdb_data_t;

typedef enum { IRIVERDB_012, IRIVERDB_016 } iriverdb_version_t;

typedef struct iriverdb {
	iriverdb_version_t version;
	GList *tracks;
} iriverdb_t;

typedef enum {
	IRIVERDB_CALLBACK_SCAN,
	IRIVERDB_CALLBACK_EXPUNGE,
} iriverdb_callback_t;

typedef struct iriverdb_device {
	int vendor_id, product_id;
	iriverdb_version_t version;
} iriverdb_device_t;

GList *iriverdb_detect( void );
GList *iriverdb_devices( void );

void iriverdb_free_database( iriverdb_t *database );

/* Normal non-callback functions
 */
int iriverdb_write( const char *path, iriverdb_version_t version );
iriverdb_t *iriverdb_read( const char *path );
int iriverdb_refresh( const char *path );

/* Callback-enabled functions
 */
int iriverdb_write_with_callback( const char *path,
				  iriverdb_version_t version,
				  void ( *callback )( const iriverdb_callback_t type,
						      const void *data ) );
iriverdb_t *iriverdb_read_with_callback( const char *path,
					 void ( *callback )( const iriverdb_callback_t type,
							     const void *data ) );
int iriverdb_refresh_with_callback( const char *path,
				    void ( *callback )( const iriverdb_callback_t type,
							const void *data ) );

#ifdef __cplusplus
}
#endif

#endif /* IRIVERDB_H */
