/* libiriverdb - unicode manipulation routines
 * Copyright 2005 Matt Dainty
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * $Id: unicode.c 32 2005-08-14 19:28:01Z  $
 */

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif /* HAVE_CONFIG_H */

#include <stdio.h>
#include <string.h>
#include <glib.h>

#include "internal.h"

/* Do all the conversion hard work
 */
static char *iriverdb_convert( const char *string,
			       int length,
			       const char *from,
			       const char *to,
			       unsigned int *size )
{

#ifdef DEBUG
	fprintf( stderr, "%s: %s string = %d byte%s long\n",
			 __func__, from, length, ( length  == 1 ) ? "" : "s" );
#endif /* DEBUG */

	char *result = g_convert( string, length, to, from, NULL, size, NULL );

	return result;
}

/* Convert ISO-8859-1 to UTF-8
 */
char *iriverdb_iso88591_to_utf8( const char *string, unsigned int *size )
{
	char *ptr;
	int i;

	for( ptr = ( char * ) string, i = 0; *ptr != 0; ptr++, i++ );

	return iriverdb_convert( string, i, "ISO-8859-1", "UTF-8", size );
}

/* Convert UTF-16BE to UTF-8
 */
char *iriverdb_utf16be_to_utf8( const char *string, unsigned int *size )
{
	guint16 *ptr;
	int i;

	for( ptr = ( guint16 * ) string, i = 0; *ptr != 0; ptr++, i += 2 );

	return iriverdb_convert( string, i, "UTF-16BE", "UTF-8", size );
}

/* Convert UCS-4LE to UTF-8
 */
char *iriverdb_ucs4le_to_utf8( const char *string, unsigned int *size )
{
	guint32 *ptr;
	int i;

	for( ptr = ( guint32 * ) string, i = 0; *ptr != 0; ptr++, i += 4 );

	return iriverdb_convert( string, i, "UCS-4LE", "UTF-8", size );
}

/* Convert UCS-4BE to UTF-8
 */
char *iriverdb_ucs4be_to_utf8( const char *string, unsigned int *size )
{
	guint32 *ptr;
	int i;

	for( ptr = ( guint32 * ) string, i = 0; *ptr != 0; ptr++, i += 4 );

	return iriverdb_convert( string, i, "UCS-4BE", "UTF-8", size );
}

/* Convert UTF-16LE to UTF-8
 */
char *iriverdb_utf16le_to_utf8( const char *string, unsigned int *size )
{
	guint16 *ptr;
	int i;

	for( ptr = ( guint16 * ) string, i = 0; *ptr != 0; ptr++, i += 2 );

	return iriverdb_convert( string, i, "UTF-16LE", "UTF-8", size );
}

/* Convert UTF-8 to UTF-16LE
 */
char *iriverdb_utf8_to_utf16le( const char *string, unsigned int *size )
{
	char *ptr;
	int i;

	for( ptr = ( char * ) string, i = 0; *ptr != 0; ptr++, i++ );

	return iriverdb_convert( string, i, "UTF-8", "UTF-16LE", size );
}
